@@ -4,6 +4,7 @@ namespace onespace\tools\activeApi\models\people;
 
 use onespace\tools\activeApi\components\clients\PeopleClient;
 use yii\helpers\ArrayHelper;
+use yii\web\NotFoundHttpException;
 
 /**
  * @property integer $id
@@ -45,6 +46,11 @@ class Person extends \onespace\tools\activeApi\models\BaseActiveApiModel {
     public $full_name;
     public $search_text;
 
+    public const STATUS_PENDING = 0;
+    public const STATUS_ACTIVE = 1;
+    public const STATUS_ARCHIVED = 2;
+    public const STATUS_BLOCKED = 3;
+
     /**
      * {@inheritdoc}
      */
@@ -135,4 +141,30 @@ class Person extends \onespace\tools\activeApi\models\BaseActiveApiModel {
             'gdpr_deleted_at' => 'Unix timestamp of when the user account behind this person GDPR deleted their account',
         ]);
     }
+
+    /**
+     * @throws  NotFoundHttpException
+     */
+    public static function findById(int $id): Person {
+        $model = self::findOne(['id' => $id]);
+
+        if ($model === null) {
+            throw new NotFoundHttpException("Person not found");
+        }
+
+        return $model;
+    }
+
+    /**
+     * @throws  NotFoundHttpException
+     */
+    public static function findByGuid(string $guid): Person {
+        $model = self::findOne(['guid' => $guid]);
+
+        if ($model === null) {
+            throw new NotFoundHttpException("Person not found");
+        }
+
+        return $model;
+    }
 }
